==> mule-metadata-model-raml-1.1.0-sources.jar: org/mule/metadata/raml/internal/fragments/handler/ObjectTypeDeclarationHandler.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.raml.internal.fragments.handler;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectFieldTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;
import org.raml.v2.api.model.v10.datamodel.ObjectTypeDeclaration;
import org.raml.v2.api.model.v10.datamodel.TypeDeclaration;

public class ObjectTypeDeclarationHandler implements TypeDeclarationHandler {

  @Override
  public boolean handles(TypeDeclaration typeDeclaration) {
    return typeDeclaration instanceof ObjectTypeDeclaration;
  }

  @Override
  public TypeBuilder<?> handle(TypeDeclaration typeDeclaration, BaseTypeBuilder root,
                               TypeDeclarationHandlerManager typeDeclarationHandlerManager,
                               ParsingContext parsingContext) {
    final ObjectTypeBuilder objectTypeBuilder = root.objectType();
    ObjectTypeDeclaration objectTypeDeclaration = (ObjectTypeDeclaration) typeDeclaration;
    parsingContext.registerTypeBuilder(objectTypeDeclaration, objectTypeBuilder);
    objectTypeDeclaration.properties().forEach(propertyTypeDeclaration -> {
      final ObjectFieldTypeBuilder objectFieldTypeBuilder = objectTypeBuilder.addField();
      objectFieldTypeBuilder.key(propertyTypeDeclaration.name());
      objectFieldTypeBuilder.value(typeDeclarationHandlerManager.handle(propertyTypeDeclaration, parsingContext));
    });
    return objectTypeBuilder;
  }
}

==> mule-metadata-model-raml-1.2.2-sources.jar: org/mule/metadata/raml/internal/fragments/handler/ObjectTypeDeclarationHandler.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.raml.internal.fragments.handler;

import org.mule.metadata.api.annotation.DefaultValueAnnotation;
import org.mule.metadata.api.annotation.DescriptionAnnotation;
import org.mule.metadata.api.annotation.ExampleAnnotation;
import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectFieldTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;

import org.raml.v2.api.model.v10.datamodel.ObjectTypeDeclaration;
import org.raml.v2.api.model.v10.datamodel.TypeDeclaration;

public class ObjectTypeDeclarationHandler implements TypeDeclarationHandler {

  @Override
  public boolean handles(TypeDeclaration typeDeclaration) {
    return typeDeclaration instanceof ObjectTypeDeclaration;
  }

  @Override
  public TypeBuilder<?> handle(TypeDeclaration typeDeclaration, BaseTypeBuilder root,
                               TypeDeclarationHandlerManager typeDeclarationHandlerManager,
                               ParsingContext parsingContext) {
    final ObjectTypeBuilder objectTypeBuilder = root.objectType();
    ObjectTypeDeclaration objectTypeDeclaration = (ObjectTypeDeclaration) typeDeclaration;
    parsingContext.registerTypeBuilder(objectTypeDeclaration, objectTypeBuilder);
    objectTypeDeclaration.properties().forEach(propertyTypeDeclaration -> {
      final ObjectFieldTypeBuilder objectFieldTypeBuilder = objectTypeBuilder.addField();
      objectFieldTypeBuilder.key(propertyTypeDeclaration.name());
      objectFieldTypeBuilder.value(typeDeclarationHandlerManager.handle(propertyTypeDeclaration, parsingContext));

      if (propertyTypeDeclaration.required()) {
        objectFieldTypeBuilder.required();
      }

      if (propertyTypeDeclaration.defaultValue() != null) {
        objectFieldTypeBuilder.with(new DefaultValueAnnotation(propertyTypeDeclaration.defaultValue()));
      }

      if (propertyTypeDeclaration.description() != null) {
        objectFieldTypeBuilder.with(new DescriptionAnnotation(propertyTypeDeclaration.description().value()));
      }

      if (propertyTypeDeclaration.example() != null) {
        objectFieldTypeBuilder.with(new ExampleAnnotation(propertyTypeDeclaration.example().value()));
      }
    });
    return objectTypeBuilder;
  }
}
